.. image:: https://travis-ci.org/asphalt-framework/asphalt-py4j.svg?branch=master
  :target: https://travis-ci.org/asphalt-framework/asphalt-py4j
  :alt: Build Status
.. image:: https://coveralls.io/repos/github/asphalt-framework/asphalt-py4j/badge.svg?branch=master
  :target: https://coveralls.io/github/asphalt-framework/asphalt-py4j?branch=master
  :alt: Code Coverage

This Asphalt framework component provides the ability to run Java code directly from Python.

It is a wrapper for the Py4J_ library.

.. _Py4J: https://www.py4j.org/
.. _Java Virtual Machine: https://en.wikipedia.org/wiki/Java_virtual_machine

Project links
-------------

* `Documentation <http://asphalt-py4j.readthedocs.org/en/latest/>`_
* `Help and support <https://github.com/asphalt-framework/asphalt/wiki/Help-and-support>`_
* `Source code <https://github.com/asphalt-framework/asphalt-py4j>`_
* `Issue tracker <https://github.com/asphalt-framework/asphalt-py4j/issues>`_
